from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_ST_STM32WB = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STM32WB10CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB10CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx0 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb10cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB10CCUx\n\nArm Cortex-M4 STM32WB STM32WBx0 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST(PB11)',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB15CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB15CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb15cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB15CCUx\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST(PB11)',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB15CCUxE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB15CCUxE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb15cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB15CCUxE\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST(PB11)',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB15CCYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB15CCYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_3.30x3.38mm_Layout7x7_P0.4mm_Offcenter'], 'footprint':'Package_CSP:ST_WLCSP-49_3.30x3.38mm_Layout7x7_P0.4mm_Offcenter', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb15cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB15CCYx\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='A1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='NRST(PB11)',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='D3',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='F2',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F4',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB30CEUxA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB30CEUxA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx0 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb30ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB30CEUxA\n\nArm Cortex-M4 STM32WB STM32WBx0 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB35C_C-E_UxA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB35C_C-E_UxA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb35cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB35C_C-E_UxA\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB50CGUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB50CGUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx0 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb50cg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB50CGUx\n\nArm Cortex-M4 STM32WB STM32WBx0 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB55CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB55CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb55cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB55CCUx\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB55CEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB55CEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb55ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB55CEUx\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB55CGUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB55CGUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb55cg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB55CGUx\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB55RCVx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB55RCVx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-68-1EP_8x8mm_P0.4mm_EP6.4x6.4mm'], 'footprint':'Package_DFN_QFN:QFN-68-1EP_8x8mm_P0.4mm_EP6.4x6.4mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb55rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB55RCVx\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='38',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB55REVx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB55REVx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-68-1EP_8x8mm_P0.4mm_EP6.4x6.4mm'], 'footprint':'Package_DFN_QFN:QFN-68-1EP_8x8mm_P0.4mm_EP6.4x6.4mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb55re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB55REVx\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='38',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB55RGVx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB55RGVx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-68-1EP_8x8mm_P0.4mm_EP6.4x6.4mm'], 'footprint':'Package_DFN_QFN:QFN-68-1EP_8x8mm_P0.4mm_EP6.4x6.4mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb55rg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB55RGVx\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='38',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PC0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB55VCQx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB55VCQx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-129_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-129_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb55vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB55VCQx\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='A1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDDCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VDDCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VSSSMPS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='H12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K12',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDDCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VSSRF',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB55VCYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB55VCYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-100_4.40x4.38mm_Layout10x10_P0.4mm_Offcenter'], 'footprint':'Package_CSP:ST_WLCSP-100_4.40x4.38mm_Layout10x10_P0.4mm_Offcenter', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb55vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB55VCYx\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='A1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H4',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='H9',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB55VEQx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB55VEQx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-129_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-129_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb55ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB55VEQx\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='A1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDDCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VDDCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VSSSMPS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='H12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K12',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDDCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VSSRF',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB55VEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB55VEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-100_4.40x4.38mm_Layout10x10_P0.4mm_Offcenter'], 'footprint':'Package_CSP:ST_WLCSP-100_4.40x4.38mm_Layout10x10_P0.4mm_Offcenter', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb55ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB55VEYx\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='A1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H4',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='H9',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB55VGQx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB55VGQx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-129_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-129_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb55vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB55VGQx\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='A1',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDDCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VDDCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VSSSMPS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='H12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K12',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDDCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VSSRF',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB55VGYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB55VGYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-100_4.40x4.38mm_Layout10x10_P0.4mm_Offcenter'], 'footprint':'Package_CSP:ST_WLCSP-100_4.40x4.38mm_Layout10x10_P0.4mm_Offcenter', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb55vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB55VGYx\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='A1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H4',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='H9',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB55VYYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB55VYYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-100_4.40x4.38mm_Layout10x10_P0.4mm_Offcenter'], 'footprint':'Package_CSP:ST_WLCSP-100_4.40x4.38mm_Layout10x10_P0.4mm_Offcenter', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb55vy.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB55VYYx\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='A1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H4',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='H9',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J6',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WBA52CEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WBA52CEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M33 STM32WBA STM32WBAx2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wba52ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WBA52CEUx\n\nArm Cortex-M33 STM32WBA STM32WBAx2', 'pins':[
            Pin(num='1',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RF',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDDHPA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDRFPA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='45',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS/VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WBA52CGUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WBA52CGUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M33 STM32WBA STM32WBAx2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wba52cg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WBA52CGUx\n\nArm Cortex-M33 STM32WBA STM32WBAx2', 'pins':[
            Pin(num='1',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RF',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDDHPA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDRFPA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='45',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS/VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB35CCUxA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB35CCUxA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb35cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB35CCUxA\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WB35CEUxA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WB35CEUxA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WB STM32WBx5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wb35ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WB.kicad_sym\nSTM32WB35CEUxA\n\nArm Cortex-M4 STM32WB STM32WBx5', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='AT0',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='AT1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])